# BagKadasterClient::AdresApi

All URIs are relative to *https://api.bag.acceptatie.kadaster.nl/lvbag/individuelebevragingen/v2*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**bevraag_adressen**](AdresApi.md#bevraag_adressen) | **GET** /adressen | Bevragen van huidige adressen met een (combinatie van) zoek parameters. |
| [**bevraag_adressen_met_num_id**](AdresApi.md#bevraag_adressen_met_num_id) | **GET** /adressen/{nummeraanduidingIdentificatie} | Bevragen van een huidig adres met de identificatie van een nummeraanduiding. |
| [**zoek**](AdresApi.md#zoek) | **GET** /adressen/zoek | Zoeken van huidige adressen |


## bevraag_adressen

> <AdresIOHalCollection> bevraag_adressen(opts)

Bevragen van huidige adressen met een (combinatie van) zoek parameters.

De volgende bevragingen worden ondersteund: <ol>   <li>     Bevragen van één huidig adres met de identificatie van een zoekresultaat verkregen via /adressen/zoek.   </li>   <li>     Bevragen van één of meer huidige adressen met postcode, huisnummer en optioneel huisnummertoevoeging en huisletter.     Parameter exacteMatch kan worden toegepast.   </li>   <li>     Bevragen van één of meer huidige adressen met de identificatie van een adresseerbaar object.   </li>   <li>     Bevragen van één of meer huidige adressen met woonplaats naam, openbare ruimte naam, huisnummer en optioneel huisnummertoevoeging en/of huisletter.     Parameter exacteMatch kan worden toegepast.   </li>   <li>     Bevragen van één of meer huidige adressen met de identificatie van een pand.     Expand wordt niet ondersteund.   </li> </ol> Bij de bovenstaande bevragingen kunnen eveneens de volgende parameters worden gebruikt (tenzij anders vermeld):<br/> Als expand=nummeraanduiding, openbareRuimte, woonplaats (of een combinatie daarvan) of als expand=true, dan worden de gevraagde of alle gerelateerde resources als geneste resource geleverd. Voor paginering, zie: [functionele specificatie paginering](https://github.com/lvbag/BAG-API/blob/master/Features/paginering.feature).

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::AdresApi.new
opts = {
  zoekresultaat_identificatie: 'zoekresultaat_identificatie_example', # String | De identificatie van een gekozen zoekresultaat uit de zoekResultatenHalCollectie verkregen bij een GET /adressen/zoek
  postcode: '6922KZ', # String | Postcode behorende bij een nummeraanduiding.
  huisnummer: 1, # Integer | Huisnummer behorende bij een nummeraanduiding.
  huisnummertoevoeging: 'bis', # String | Huisnummertoevoeging behorende bij een nummeraanduiding.
  huisletter: 'A', # String | Huisletter behorende bij een nummeraanduiding.
  exacte_match: true, # Boolean | \"Een indicatie of de resultaten van een zoekoperatie exact overeen moeten komen met de zoekcriteria, zie [functionele specificatie exacte match](https://github.com/lvbag/BAG-API/blob/master/Features/exacte_match.feature).\"
  adresseerbaar_object_identificatie: '0226010000038820', # String | Identificatie van een adresseerbaar object (ligplaats, standplaats of verblijfsobject) uit de BAG.
  woonplaats_naam: 'Duiven', # String | Naam van een woonplaats.
  openbare_ruimte_naam: 'Laan van de landinrichtingscommissie Duiven-Westervoort', # String | Naam van een openbare ruimte.
  pand_identificatie: '0226100000008856', # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
  expand: 'expand_example', # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
  page: 56, # Integer | Pagina nummer
  page_size: 56 # Integer | Aantal resultaten per pagina
}

begin
  # Bevragen van huidige adressen met een (combinatie van) zoek parameters.
  result = api_instance.bevraag_adressen(opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresApi->bevraag_adressen: #{e}"
end
```

#### Using the bevraag_adressen_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AdresIOHalCollection>, Integer, Hash)> bevraag_adressen_with_http_info(opts)

```ruby
begin
  # Bevragen van huidige adressen met een (combinatie van) zoek parameters.
  data, status_code, headers = api_instance.bevraag_adressen_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AdresIOHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresApi->bevraag_adressen_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **zoekresultaat_identificatie** | **String** | De identificatie van een gekozen zoekresultaat uit de zoekResultatenHalCollectie verkregen bij een GET /adressen/zoek | [optional] |
| **postcode** | **String** | Postcode behorende bij een nummeraanduiding. | [optional] |
| **huisnummer** | **Integer** | Huisnummer behorende bij een nummeraanduiding. | [optional] |
| **huisnummertoevoeging** | **String** | Huisnummertoevoeging behorende bij een nummeraanduiding. | [optional] |
| **huisletter** | **String** | Huisletter behorende bij een nummeraanduiding. | [optional] |
| **exacte_match** | **Boolean** | \&quot;Een indicatie of de resultaten van een zoekoperatie exact overeen moeten komen met de zoekcriteria, zie [functionele specificatie exacte match](https://github.com/lvbag/BAG-API/blob/master/Features/exacte_match.feature).\&quot; | [optional][default to false] |
| **adresseerbaar_object_identificatie** | **String** | Identificatie van een adresseerbaar object (ligplaats, standplaats of verblijfsobject) uit de BAG. | [optional] |
| **woonplaats_naam** | **String** | Naam van een woonplaats. | [optional] |
| **openbare_ruimte_naam** | **String** | Naam van een openbare ruimte. | [optional] |
| **pand_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. | [optional] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |
| **page** | **Integer** | Pagina nummer | [optional][default to 1] |
| **page_size** | **Integer** | Aantal resultaten per pagina | [optional][default to 20] |

### Return type

[**AdresIOHalCollection**](AdresIOHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## bevraag_adressen_met_num_id

> <AdresIOHal> bevraag_adressen_met_num_id(nummeraanduiding_identificatie, opts)

Bevragen van een huidig adres met de identificatie van een nummeraanduiding.

Bevragen van een huidig adres met de identificatie van een nummeraanduiding. Als expand=nummeraanduiding, openbareRuimte, woonplaats (of een combinatie daarvan) of als expand=true, dan worden de gevraagde of alle gerelateerde resources als geneste resource geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::AdresApi.new
nummeraanduiding_identificatie = '0226200000038923' # String | Identificatie van een nummeraanduiding uit de BAG. Deze is 16 cijfers lang.
opts = {
  expand: 'expand_example' # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
}

begin
  # Bevragen van een huidig adres met de identificatie van een nummeraanduiding.
  result = api_instance.bevraag_adressen_met_num_id(nummeraanduiding_identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresApi->bevraag_adressen_met_num_id: #{e}"
end
```

#### Using the bevraag_adressen_met_num_id_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AdresIOHal>, Integer, Hash)> bevraag_adressen_met_num_id_with_http_info(nummeraanduiding_identificatie, opts)

```ruby
begin
  # Bevragen van een huidig adres met de identificatie van een nummeraanduiding.
  data, status_code, headers = api_instance.bevraag_adressen_met_num_id_with_http_info(nummeraanduiding_identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AdresIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresApi->bevraag_adressen_met_num_id_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **nummeraanduiding_identificatie** | **String** | Identificatie van een nummeraanduiding uit de BAG. Deze is 16 cijfers lang. |  |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |

### Return type

[**AdresIOHal**](AdresIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## zoek

> <ZoekResultaatHalCollection> zoek(zoek, opts)

Zoeken van huidige adressen

Zoeken van huidige adressen met postcode, woonplaats, straatnaam, huisnummer, huisletter, huisnummertoevoeging.  Een adres kan worden gevonden door de zoekresultaatidentificatie uit het antwoord als parameter mee te geven in get /adressen. Voor paginering, zie: [functionele specificatie paginering](https://github.com/lvbag/BAG-API/blob/master/Features/paginering.feature).

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::AdresApi.new
zoek = 'zoek_example' # String | Zoekterm op postcode, woonplaats, straatnaam, huisnummer, huisletter, huisnummertoevoeging
opts = {
  page: 56, # Integer | Pagina nummer
  page_size: 56 # Integer | Aantal resultaten per pagina
}

begin
  # Zoeken van huidige adressen
  result = api_instance.zoek(zoek, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresApi->zoek: #{e}"
end
```

#### Using the zoek_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ZoekResultaatHalCollection>, Integer, Hash)> zoek_with_http_info(zoek, opts)

```ruby
begin
  # Zoeken van huidige adressen
  data, status_code, headers = api_instance.zoek_with_http_info(zoek, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ZoekResultaatHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresApi->zoek_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **zoek** | **String** | Zoekterm op postcode, woonplaats, straatnaam, huisnummer, huisletter, huisnummertoevoeging |  |
| **page** | **Integer** | Pagina nummer | [optional][default to 1] |
| **page_size** | **Integer** | Aantal resultaten per pagina | [optional][default to 20] |

### Return type

[**ZoekResultaatHalCollection**](ZoekResultaatHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json

