# BagKadasterClient::AdresseerbaarObjectApi

All URIs are relative to *https://api.bag.acceptatie.kadaster.nl/lvbag/individuelebevragingen/v2*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**bevragen_adresseerbaar_object**](AdresseerbaarObjectApi.md#bevragen_adresseerbaar_object) | **GET** /adresseerbareobjecten/{adresseerbaarObjectIdentificatie} | Bevragen van één adresseerbaar object met een adresseerbaar object identificatie. |
| [**bevragen_adresseerbaar_object_lvc**](AdresseerbaarObjectApi.md#bevragen_adresseerbaar_object_lvc) | **GET** /adresseerbareobjecten/{adresseerbaarObjectIdentificatie}/lvc | Bevragen van de levenscyclus van een adresseerbaar object met een adresseerbaar object identificatie. |
| [**zoek_adresseerbaar_object**](AdresseerbaarObjectApi.md#zoek_adresseerbaar_object) | **GET** /adresseerbareobjecten | Bevragen van één of meer adresseerbare objecten op basis van een nummeraanduiding identificatie. |


## bevragen_adresseerbaar_object

> <AdresseerbaarObjectIOHal> bevragen_adresseerbaar_object(adresseerbaar_object_identificatie, opts)

Bevragen van één adresseerbaar object met een adresseerbaar object identificatie.

Bevragen van één adresseerbaar object (ligplaats, standplaats of verblijfsobject) met de identificatie van een adresseerbaar object. Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd.  Als expand=heeftAlsHoofdAdres, heeftAlsNevenAdres, maaktDeelUitVan (of een combinatie daarvan) of als expand=true, dan worden de gevraagde of alle gerelateerde resources als geneste resource geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::AdresseerbaarObjectApi.new
adresseerbaar_object_identificatie = '0226010000038820' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
opts = {
  geldig_op: Date.parse('2019-06-01'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum 'YYYY-MM-DD' Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn gekomen op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss'. Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  expand: 'expand_example', # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # Bevragen van één adresseerbaar object met een adresseerbaar object identificatie.
  result = api_instance.bevragen_adresseerbaar_object(adresseerbaar_object_identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresseerbaarObjectApi->bevragen_adresseerbaar_object: #{e}"
end
```

#### Using the bevragen_adresseerbaar_object_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AdresseerbaarObjectIOHal>, Integer, Hash)> bevragen_adresseerbaar_object_with_http_info(adresseerbaar_object_identificatie, opts)

```ruby
begin
  # Bevragen van één adresseerbaar object met een adresseerbaar object identificatie.
  data, status_code, headers = api_instance.bevragen_adresseerbaar_object_with_http_info(adresseerbaar_object_identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AdresseerbaarObjectIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresseerbaarObjectApi->bevragen_adresseerbaar_object_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **adresseerbaar_object_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#39;YYYY-MM-DD&#39; Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn gekomen op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39;. Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**AdresseerbaarObjectIOHal**](AdresseerbaarObjectIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## bevragen_adresseerbaar_object_lvc

> <AdresseerbaarObjectLvcIOHalCollection> bevragen_adresseerbaar_object_lvc(adresseerbaar_object_identificatie, opts)

Bevragen van de levenscyclus van een adresseerbaar object met een adresseerbaar object identificatie.

Bevragen van de levenscyclus van een adresseerbaar object (ligplaats, standplaats of verblijfsobject) met de identificatie van een adresseerbaar object. Met de geheleLvc parameter kan worden aangegeven of de gehele levenscyclus (inclusief voorkomens die uit de geldige levenscyclus zijn verwijderd) of alleen de actieve levenscyclus (alleen de voorkomens die onderdeel zijn van de geldige levenscyclus) gewenst zijn. 

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::AdresseerbaarObjectApi.new
adresseerbaar_object_identificatie = '0226010000038820' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
opts = {
  gehele_lvc: true, # Boolean | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false). 
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # Bevragen van de levenscyclus van een adresseerbaar object met een adresseerbaar object identificatie.
  result = api_instance.bevragen_adresseerbaar_object_lvc(adresseerbaar_object_identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresseerbaarObjectApi->bevragen_adresseerbaar_object_lvc: #{e}"
end
```

#### Using the bevragen_adresseerbaar_object_lvc_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AdresseerbaarObjectLvcIOHalCollection>, Integer, Hash)> bevragen_adresseerbaar_object_lvc_with_http_info(adresseerbaar_object_identificatie, opts)

```ruby
begin
  # Bevragen van de levenscyclus van een adresseerbaar object met een adresseerbaar object identificatie.
  data, status_code, headers = api_instance.bevragen_adresseerbaar_object_lvc_with_http_info(adresseerbaar_object_identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AdresseerbaarObjectLvcIOHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresseerbaarObjectApi->bevragen_adresseerbaar_object_lvc_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **adresseerbaar_object_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **gehele_lvc** | **Boolean** | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false).  | [optional][default to false] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**AdresseerbaarObjectLvcIOHalCollection**](AdresseerbaarObjectLvcIOHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## zoek_adresseerbaar_object

> <AdresseerbareObjectenIOHalCollection> zoek_adresseerbaar_object(opts)

Bevragen van één of meer adresseerbare objecten op basis van een nummeraanduiding identificatie.

Bevragen/zoeken van alle aan een nummeraanduiding identificatie gerelateerde adresseerbare objecten (ligplaats, standplaats of verblijfsobject). Parameter huidig kan worden toegepast. Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd.  Als expand=heeftAlsHoofdAdres, heeftAlsNevenAdres, maaktDeelUitVan (of een combinatie daarvan) of als expand=true, dan worden de gevraagde of alle gerelateerde resources als geneste resource geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::AdresseerbaarObjectApi.new
opts = {
  nummeraanduiding_identificatie: '0226200000038923', # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
  huidig: false, # Boolean | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn.
  geldig_op: Date.parse('2019-06-01'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum 'YYYY-MM-DD' Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn gekomen op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss'. Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  expand: 'expand_example', # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # Bevragen van één of meer adresseerbare objecten op basis van een nummeraanduiding identificatie.
  result = api_instance.zoek_adresseerbaar_object(opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresseerbaarObjectApi->zoek_adresseerbaar_object: #{e}"
end
```

#### Using the zoek_adresseerbaar_object_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<AdresseerbareObjectenIOHalCollection>, Integer, Hash)> zoek_adresseerbaar_object_with_http_info(opts)

```ruby
begin
  # Bevragen van één of meer adresseerbare objecten op basis van een nummeraanduiding identificatie.
  data, status_code, headers = api_instance.zoek_adresseerbaar_object_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <AdresseerbareObjectenIOHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling AdresseerbaarObjectApi->zoek_adresseerbaar_object_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **nummeraanduiding_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. | [optional] |
| **huidig** | **Boolean** | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn. | [optional][default to false] |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#39;YYYY-MM-DD&#39; Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn gekomen op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39;. Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**AdresseerbareObjectenIOHalCollection**](AdresseerbareObjectenIOHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json

