# BagKadasterClient::BronhouderApi

All URIs are relative to *https://api.bag.acceptatie.kadaster.nl/lvbag/individuelebevragingen/v2*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**bevragen_bronhouder**](BronhouderApi.md#bevragen_bronhouder) | **GET** /bronhouders/{identificatie} | Bevragen bronhouder met de bronhouder identificatie (gemeentecode). |
| [**bronhouder_identificatie_voorkomen**](BronhouderApi.md#bronhouder_identificatie_voorkomen) | **GET** /bronhouders/{identificatie}/{versie}/{timestampRegistratieLv} | bevragen voorkomen van een bronhouder met de identificatie van een bronhouder en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG. |
| [**zoek_bronhouder**](BronhouderApi.md#zoek_bronhouder) | **GET** /bronhouders | Bevragen bronhouder met een object identificatie. |


## bevragen_bronhouder

> <BronhouderHal> bevragen_bronhouder(identificatie, opts)

Bevragen bronhouder met de bronhouder identificatie (gemeentecode).

Bevragen/raadplegen van een bronhouder met de identificatie van een bronhouder (gemeentecode). Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::BronhouderApi.new
identificatie = '0226' # String | Een officiële code die aan een gemeente is toegekend, ontleend is aan tabel 33.
opts = {
  geldig_op: Date.parse('Sat Jun 01 00:00:00 UTC 2019'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum 'YYYY-MM-DD' Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00') # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
}

begin
  # Bevragen bronhouder met de bronhouder identificatie (gemeentecode).
  result = api_instance.bevragen_bronhouder(identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling BronhouderApi->bevragen_bronhouder: #{e}"
end
```

#### Using the bevragen_bronhouder_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BronhouderHal>, Integer, Hash)> bevragen_bronhouder_with_http_info(identificatie, opts)

```ruby
begin
  # Bevragen bronhouder met de bronhouder identificatie (gemeentecode).
  data, status_code, headers = api_instance.bevragen_bronhouder_with_http_info(identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BronhouderHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling BronhouderApi->bevragen_bronhouder_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **identificatie** | **String** | Een officiële code die aan een gemeente is toegekend, ontleend is aan tabel 33. |  |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#39;YYYY-MM-DD&#39; Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |

### Return type

[**BronhouderHal**](BronhouderHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## bronhouder_identificatie_voorkomen

> <BronhouderHal> bronhouder_identificatie_voorkomen(identificatie, versie, timestamp_registratie_lv)

bevragen voorkomen van een bronhouder met de identificatie van een bronhouder en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.

Bevragen/raadplegen van een voorkomen van een bronhouder met de identificatie van een bronhouder en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::BronhouderApi.new
identificatie = '0226' # String | Een officiële code die aan een gemeente is toegekend, ontleend is aan tabel 33.
versie = 1 # Integer | De versie van een voorkomen van een object
timestamp_registratie_lv = '1530403860000' # String | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG

begin
  # bevragen voorkomen van een bronhouder met de identificatie van een bronhouder en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.
  result = api_instance.bronhouder_identificatie_voorkomen(identificatie, versie, timestamp_registratie_lv)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling BronhouderApi->bronhouder_identificatie_voorkomen: #{e}"
end
```

#### Using the bronhouder_identificatie_voorkomen_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BronhouderHal>, Integer, Hash)> bronhouder_identificatie_voorkomen_with_http_info(identificatie, versie, timestamp_registratie_lv)

```ruby
begin
  # bevragen voorkomen van een bronhouder met de identificatie van een bronhouder en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.
  data, status_code, headers = api_instance.bronhouder_identificatie_voorkomen_with_http_info(identificatie, versie, timestamp_registratie_lv)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BronhouderHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling BronhouderApi->bronhouder_identificatie_voorkomen_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **identificatie** | **String** | Een officiële code die aan een gemeente is toegekend, ontleend is aan tabel 33. |  |
| **versie** | **Integer** | De versie van een voorkomen van een object |  |
| **timestamp_registratie_lv** | **String** | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG |  |

### Return type

[**BronhouderHal**](BronhouderHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## zoek_bronhouder

> <BronhouderHalCollection> zoek_bronhouder(opts)

Bevragen bronhouder met een object identificatie.

Bevragen/raadplegen van een bronhouder met de identificatie van een object. De identificatie van één van de objecten: woonplaats, openbare ruimte, nummeraanduiding, ligplaats, standplaats, verblijfsobject of pand dient gespecificeerd te worden:<br/> Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::BronhouderApi.new
opts = {
  woonplaats_identificatie: '2096', # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
  object_identificatie: '0226100000008856', # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
  geldig_op: Date.parse('Sat Jun 01 00:00:00 UTC 2019'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum 'YYYY-MM-DD' Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00') # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
}

begin
  # Bevragen bronhouder met een object identificatie.
  result = api_instance.zoek_bronhouder(opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling BronhouderApi->zoek_bronhouder: #{e}"
end
```

#### Using the zoek_bronhouder_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BronhouderHalCollection>, Integer, Hash)> zoek_bronhouder_with_http_info(opts)

```ruby
begin
  # Bevragen bronhouder met een object identificatie.
  data, status_code, headers = api_instance.zoek_bronhouder_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BronhouderHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling BronhouderApi->zoek_bronhouder_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **woonplaats_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. | [optional] |
| **object_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. | [optional] |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#39;YYYY-MM-DD&#39; Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |

### Return type

[**BronhouderHalCollection**](BronhouderHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json

