# BagKadasterClient::NummeraanduidingApi

All URIs are relative to *https://api.bag.acceptatie.kadaster.nl/lvbag/individuelebevragingen/v2*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**nummeraanduiding_identificatie**](NummeraanduidingApi.md#nummeraanduiding_identificatie) | **GET** /nummeraanduidingen/{nummeraanduidingIdentificatie} | bevragen van een nummeraanduiding op basis van de identificatie van een nummeraanduiding |
| [**nummeraanduiding_identificatie_voorkomen**](NummeraanduidingApi.md#nummeraanduiding_identificatie_voorkomen) | **GET** /nummeraanduidingen/{nummeraanduidingIdentificatie}/{versie}/{timestampRegistratieLv} | bevragen van een voorkomen van een nummeraanduiding, op basis van de identificatie van een nummeraanduiding en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG. |
| [**nummeraanduiding_lvc_identificatie**](NummeraanduidingApi.md#nummeraanduiding_lvc_identificatie) | **GET** /nummeraanduidingen/{nummeraanduidingIdentificatie}/lvc | bevragen levenscyclus van een nummeraanduiding met de identificatie van een nummeraanduiding. |
| [**zoek_nummeraanduiding**](NummeraanduidingApi.md#zoek_nummeraanduiding) | **GET** /nummeraanduidingen | bevragen nummeraanduiding(en) op basis van verschillende combinaties van parameters. |


## nummeraanduiding_identificatie

> <NummeraanduidingIOHal> nummeraanduiding_identificatie(nummeraanduiding_identificatie, opts)

bevragen van een nummeraanduiding op basis van de identificatie van een nummeraanduiding

Bevragen/raadplegen van één nummeraanduiding met de identificatie van een nummeraanduiding. Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd.  Als expand=ligtInWoonplaats, ligtAanOpenbareRuimte of als expand=true dan worden de gevraagde of alle gerelateerde objecten als geneste resources geleverd. 

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::NummeraanduidingApi.new
nummeraanduiding_identificatie = '0226200000038923' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
opts = {
  geldig_op: Date.parse('2019-12-01'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum 'YYYY-MM-DD'  Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  expand: 'expand_example' # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
}

begin
  # bevragen van een nummeraanduiding op basis van de identificatie van een nummeraanduiding
  result = api_instance.nummeraanduiding_identificatie(nummeraanduiding_identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling NummeraanduidingApi->nummeraanduiding_identificatie: #{e}"
end
```

#### Using the nummeraanduiding_identificatie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<NummeraanduidingIOHal>, Integer, Hash)> nummeraanduiding_identificatie_with_http_info(nummeraanduiding_identificatie, opts)

```ruby
begin
  # bevragen van een nummeraanduiding op basis van de identificatie van een nummeraanduiding
  data, status_code, headers = api_instance.nummeraanduiding_identificatie_with_http_info(nummeraanduiding_identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <NummeraanduidingIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling NummeraanduidingApi->nummeraanduiding_identificatie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **nummeraanduiding_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#39;YYYY-MM-DD&#39;  Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |

### Return type

[**NummeraanduidingIOHal**](NummeraanduidingIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## nummeraanduiding_identificatie_voorkomen

> <NummeraanduidingIOHal> nummeraanduiding_identificatie_voorkomen(nummeraanduiding_identificatie, versie, timestamp_registratie_lv)

bevragen van een voorkomen van een nummeraanduiding, op basis van de identificatie van een nummeraanduiding en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.

Bevragen/raadplegen van een voorkomen van een nummeraanduiding met de identificatie van een nummeraanduiding en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::NummeraanduidingApi.new
nummeraanduiding_identificatie = '0226200000038923' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
versie = 1 # Integer | De versie van een voorkomen van een object
timestamp_registratie_lv = '1530403860000' # String | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG

begin
  # bevragen van een voorkomen van een nummeraanduiding, op basis van de identificatie van een nummeraanduiding en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.
  result = api_instance.nummeraanduiding_identificatie_voorkomen(nummeraanduiding_identificatie, versie, timestamp_registratie_lv)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling NummeraanduidingApi->nummeraanduiding_identificatie_voorkomen: #{e}"
end
```

#### Using the nummeraanduiding_identificatie_voorkomen_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<NummeraanduidingIOHal>, Integer, Hash)> nummeraanduiding_identificatie_voorkomen_with_http_info(nummeraanduiding_identificatie, versie, timestamp_registratie_lv)

```ruby
begin
  # bevragen van een voorkomen van een nummeraanduiding, op basis van de identificatie van een nummeraanduiding en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.
  data, status_code, headers = api_instance.nummeraanduiding_identificatie_voorkomen_with_http_info(nummeraanduiding_identificatie, versie, timestamp_registratie_lv)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <NummeraanduidingIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling NummeraanduidingApi->nummeraanduiding_identificatie_voorkomen_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **nummeraanduiding_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **versie** | **Integer** | De versie van een voorkomen van een object |  |
| **timestamp_registratie_lv** | **String** | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG |  |

### Return type

[**NummeraanduidingIOHal**](NummeraanduidingIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## nummeraanduiding_lvc_identificatie

> <NummeraanduidingIOLvcHalCollection> nummeraanduiding_lvc_identificatie(nummeraanduiding_identificatie, opts)

bevragen levenscyclus van een nummeraanduiding met de identificatie van een nummeraanduiding.

Bevragen/raadplegen van de levenscyclus van één nummeraanduiding met de identificatie van een nummeraanduiding. 

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::NummeraanduidingApi.new
nummeraanduiding_identificatie = '0226200000038923' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
opts = {
  gehele_lvc: true # Boolean | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false). Voor een toelichting zie de [Praktijkhandleiding BAG](https://imbag.github.io/praktijkhandleiding/artikelen/wat-is-het-verschil-tussen-actieve-voorkomens-actuele-voorkomens-en-huidige-voorkomens).
}

begin
  # bevragen levenscyclus van een nummeraanduiding met de identificatie van een nummeraanduiding.
  result = api_instance.nummeraanduiding_lvc_identificatie(nummeraanduiding_identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling NummeraanduidingApi->nummeraanduiding_lvc_identificatie: #{e}"
end
```

#### Using the nummeraanduiding_lvc_identificatie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<NummeraanduidingIOLvcHalCollection>, Integer, Hash)> nummeraanduiding_lvc_identificatie_with_http_info(nummeraanduiding_identificatie, opts)

```ruby
begin
  # bevragen levenscyclus van een nummeraanduiding met de identificatie van een nummeraanduiding.
  data, status_code, headers = api_instance.nummeraanduiding_lvc_identificatie_with_http_info(nummeraanduiding_identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <NummeraanduidingIOLvcHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling NummeraanduidingApi->nummeraanduiding_lvc_identificatie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **nummeraanduiding_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **gehele_lvc** | **Boolean** | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false). Voor een toelichting zie de [Praktijkhandleiding BAG](https://imbag.github.io/praktijkhandleiding/artikelen/wat-is-het-verschil-tussen-actieve-voorkomens-actuele-voorkomens-en-huidige-voorkomens). | [optional][default to false] |

### Return type

[**NummeraanduidingIOLvcHalCollection**](NummeraanduidingIOLvcHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## zoek_nummeraanduiding

> <NummeraanduidingIOHalCollection> zoek_nummeraanduiding(opts)

bevragen nummeraanduiding(en) op basis van verschillende combinaties van parameters.

De volgende (combinaties van) parameters worden ondersteund:  1. Bevragen/raadplegen van een (collectie van) nummeraanduiding(en) met postcode en huisnummer (evt. met huisletter en huisnummertoevoeging).  2. Bevragen/raadplegen van een (collectie van) nummeraanduiding(en) met woonplaats naam, openbare ruimte naam, huisnummer en optioneel huisnummertoevoeging en huisletter.  3. Bevragen/zoeken van alle aan een openbare ruimte gerelateerde nummeraanduidingen met een openbare ruimte identificatie.     Expand wordt niet ondersteund.     4. Bevragen/zoeken van nummeraanduidingen met een pand identificatie. Expand wordt niet ondersteund.         Bij de bovenstaande bevragingen kunnen (tenzij anders vermeld) de volgende parameters worden gebruikt: geldigOp, beschikbaarOp, huidig, page en pageSize.  Voor paginering, zie: [functionele specificatie paginering](https://github.com/lvbag/BAG-API/blob/master/Features/paginering.feature). Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd. Parameter huidig kan worden toegepast. Als expand=ligtInWoonplaats, ligtAanOpenbareRuimte of als expand=true dan worden de gevraagde of alle gerelateerde objecten als geneste resources geleverd.  Met de exacteMatch parameter kan worden aangegeven dat alleen object(en) die exact overeenkomen met de opgegeven parameters, geretourneerd moeten worden. 

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::NummeraanduidingApi.new
opts = {
  postcode: '6922KZ', # String | Postcode behorende bij een nummeraanduiding.
  huisnummer: 1, # Integer | Huisnummer behorende bij een nummeraanduiding.
  huisnummertoevoeging: 'bis', # String | Huisnummertoevoeging behorende bij een nummeraanduiding.
  huisletter: 'A', # String | Huisletter behorende bij een nummeraanduiding.
  exacte_match: true, # Boolean | \"Een indicatie of de resultaten van een zoekoperatie exact overeen moeten komen met de zoekcriteria, zie [functionele specificatie exacte match](https://github.com/lvbag/BAG-API/blob/master/Features/exacte_match.feature).\"
  woonplaats_naam: 'Duiven', # String | Naam van een woonplaats.
  openbare_ruimte_naam: 'Laan van de landinrichtingscommissie Duiven-Westervoort', # String | Naam van een openbare ruimte.
  openbare_ruimte_identificatie: '0226300000136124', # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
  huidig: false, # Boolean | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn.
  geldig_op: Date.parse('2019-12-01'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum 'YYYY-MM-DD'  Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  page: 56, # Integer | Pagina nummer
  page_size: 56, # Integer | Aantal resultaten per pagina
  expand: 'expand_example', # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
  pand_identificatie: '0226100000008856' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
}

begin
  # bevragen nummeraanduiding(en) op basis van verschillende combinaties van parameters.
  result = api_instance.zoek_nummeraanduiding(opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling NummeraanduidingApi->zoek_nummeraanduiding: #{e}"
end
```

#### Using the zoek_nummeraanduiding_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<NummeraanduidingIOHalCollection>, Integer, Hash)> zoek_nummeraanduiding_with_http_info(opts)

```ruby
begin
  # bevragen nummeraanduiding(en) op basis van verschillende combinaties van parameters.
  data, status_code, headers = api_instance.zoek_nummeraanduiding_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <NummeraanduidingIOHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling NummeraanduidingApi->zoek_nummeraanduiding_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **postcode** | **String** | Postcode behorende bij een nummeraanduiding. | [optional] |
| **huisnummer** | **Integer** | Huisnummer behorende bij een nummeraanduiding. | [optional] |
| **huisnummertoevoeging** | **String** | Huisnummertoevoeging behorende bij een nummeraanduiding. | [optional] |
| **huisletter** | **String** | Huisletter behorende bij een nummeraanduiding. | [optional] |
| **exacte_match** | **Boolean** | \&quot;Een indicatie of de resultaten van een zoekoperatie exact overeen moeten komen met de zoekcriteria, zie [functionele specificatie exacte match](https://github.com/lvbag/BAG-API/blob/master/Features/exacte_match.feature).\&quot; | [optional][default to false] |
| **woonplaats_naam** | **String** | Naam van een woonplaats. | [optional] |
| **openbare_ruimte_naam** | **String** | Naam van een openbare ruimte. | [optional] |
| **openbare_ruimte_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. | [optional] |
| **huidig** | **Boolean** | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn. | [optional][default to false] |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#39;YYYY-MM-DD&#39;  Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **page** | **Integer** | Pagina nummer | [optional][default to 1] |
| **page_size** | **Integer** | Aantal resultaten per pagina | [optional][default to 20] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |
| **pand_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. | [optional] |

### Return type

[**NummeraanduidingIOHalCollection**](NummeraanduidingIOHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json

