# BagKadasterClient::OpenbareRuimteApi

All URIs are relative to *https://api.bag.acceptatie.kadaster.nl/lvbag/individuelebevragingen/v2*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**openbareruimte_identificatie**](OpenbareRuimteApi.md#openbareruimte_identificatie) | **GET** /openbareruimten/{openbareRuimteIdentificatie} | bevragen van een openbare ruimte met de identificatie van een openbare ruimte. |
| [**openbareruimte_identificatie_voorkomen**](OpenbareRuimteApi.md#openbareruimte_identificatie_voorkomen) | **GET** /openbareruimten/{openbareRuimteIdentificatie}/{versie}/{timestampRegistratieLv} | bevragen van een voorkomen van een openbare ruimte met de identificatie van een openbare ruimte en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG. |
| [**openbareruimte_lvc_identificatie**](OpenbareRuimteApi.md#openbareruimte_lvc_identificatie) | **GET** /openbareruimten/{openbareRuimteIdentificatie}/lvc | bevragen levenscyclus van een openbare ruimte met de identificatie van een openbare ruimte. |
| [**zoek_openbare_ruimten**](OpenbareRuimteApi.md#zoek_openbare_ruimten) | **GET** /openbareruimten | bevragen openbare ruimte(n) op basis van de verschillende combinaties van parameters. |


## openbareruimte_identificatie

> <OpenbareRuimteIOHal> openbareruimte_identificatie(openbare_ruimte_identificatie, opts)

bevragen van een openbare ruimte met de identificatie van een openbare ruimte.

Bevragen/raadplegen van een openbare ruimte met de identificatie van een openbare ruimte. Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd.  Als expand=ligtInWoonplaats of true dan wordt de woonplaats als geneste resource geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::OpenbareRuimteApi.new
openbare_ruimte_identificatie = '0226300000136124' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
opts = {
  geldig_op: Date.parse('2019-06-01'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum 'YYYY-MM-DD'  Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  expand: 'expand_example' # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
}

begin
  # bevragen van een openbare ruimte met de identificatie van een openbare ruimte.
  result = api_instance.openbareruimte_identificatie(openbare_ruimte_identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling OpenbareRuimteApi->openbareruimte_identificatie: #{e}"
end
```

#### Using the openbareruimte_identificatie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<OpenbareRuimteIOHal>, Integer, Hash)> openbareruimte_identificatie_with_http_info(openbare_ruimte_identificatie, opts)

```ruby
begin
  # bevragen van een openbare ruimte met de identificatie van een openbare ruimte.
  data, status_code, headers = api_instance.openbareruimte_identificatie_with_http_info(openbare_ruimte_identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <OpenbareRuimteIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling OpenbareRuimteApi->openbareruimte_identificatie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **openbare_ruimte_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#39;YYYY-MM-DD&#39;  Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |

### Return type

[**OpenbareRuimteIOHal**](OpenbareRuimteIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## openbareruimte_identificatie_voorkomen

> <OpenbareRuimteIOHal> openbareruimte_identificatie_voorkomen(openbare_ruimte_identificatie, versie, timestamp_registratie_lv)

bevragen van een voorkomen van een openbare ruimte met de identificatie van een openbare ruimte en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.

Bevragen/raadplegen van een voorkomen van een openbare ruimte met de identificatie van een openbare ruimte en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::OpenbareRuimteApi.new
openbare_ruimte_identificatie = '0226300000136124' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
versie = 1 # Integer | De versie van een voorkomen van een object
timestamp_registratie_lv = '1530403860000' # String | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG

begin
  # bevragen van een voorkomen van een openbare ruimte met de identificatie van een openbare ruimte en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.
  result = api_instance.openbareruimte_identificatie_voorkomen(openbare_ruimte_identificatie, versie, timestamp_registratie_lv)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling OpenbareRuimteApi->openbareruimte_identificatie_voorkomen: #{e}"
end
```

#### Using the openbareruimte_identificatie_voorkomen_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<OpenbareRuimteIOHal>, Integer, Hash)> openbareruimte_identificatie_voorkomen_with_http_info(openbare_ruimte_identificatie, versie, timestamp_registratie_lv)

```ruby
begin
  # bevragen van een voorkomen van een openbare ruimte met de identificatie van een openbare ruimte en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.
  data, status_code, headers = api_instance.openbareruimte_identificatie_voorkomen_with_http_info(openbare_ruimte_identificatie, versie, timestamp_registratie_lv)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <OpenbareRuimteIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling OpenbareRuimteApi->openbareruimte_identificatie_voorkomen_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **openbare_ruimte_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **versie** | **Integer** | De versie van een voorkomen van een object |  |
| **timestamp_registratie_lv** | **String** | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG |  |

### Return type

[**OpenbareRuimteIOHal**](OpenbareRuimteIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## openbareruimte_lvc_identificatie

> <OpenbareRuimteIOLvcHalCollection> openbareruimte_lvc_identificatie(openbare_ruimte_identificatie, opts)

bevragen levenscyclus van een openbare ruimte met de identificatie van een openbare ruimte.

Bevragen/raadplegen van de levenscyclus van één openbare ruimte, via de identificatie van een openbare ruimte.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::OpenbareRuimteApi.new
openbare_ruimte_identificatie = '0226300000136124' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
opts = {
  gehele_lvc: true # Boolean | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false). Voor een toelichting zie de [Praktijkhandleiding BAG](https://imbag.github.io/praktijkhandleiding/artikelen/wat-is-het-verschil-tussen-actieve-voorkomens-actuele-voorkomens-en-huidige-voorkomens).
}

begin
  # bevragen levenscyclus van een openbare ruimte met de identificatie van een openbare ruimte.
  result = api_instance.openbareruimte_lvc_identificatie(openbare_ruimte_identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling OpenbareRuimteApi->openbareruimte_lvc_identificatie: #{e}"
end
```

#### Using the openbareruimte_lvc_identificatie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<OpenbareRuimteIOLvcHalCollection>, Integer, Hash)> openbareruimte_lvc_identificatie_with_http_info(openbare_ruimte_identificatie, opts)

```ruby
begin
  # bevragen levenscyclus van een openbare ruimte met de identificatie van een openbare ruimte.
  data, status_code, headers = api_instance.openbareruimte_lvc_identificatie_with_http_info(openbare_ruimte_identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <OpenbareRuimteIOLvcHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling OpenbareRuimteApi->openbareruimte_lvc_identificatie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **openbare_ruimte_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **gehele_lvc** | **Boolean** | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false). Voor een toelichting zie de [Praktijkhandleiding BAG](https://imbag.github.io/praktijkhandleiding/artikelen/wat-is-het-verschil-tussen-actieve-voorkomens-actuele-voorkomens-en-huidige-voorkomens). | [optional][default to false] |

### Return type

[**OpenbareRuimteIOLvcHalCollection**](OpenbareRuimteIOLvcHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## zoek_openbare_ruimten

> <OpenbareRuimteIOHalCollection> zoek_openbare_ruimten(opts)

bevragen openbare ruimte(n) op basis van de verschillende combinaties van parameters.

De volgende (combinaties van) parameters worden ondersteund:<br/> <ol>   <li>     Bevragen/raadplegen van een openbare ruimte met een woonplaats naam en een openbare ruimte naam.     Als expand=ligtInWoonplaats of true dan wordt de woonplaats als geneste resource geleverd.   </li>   <li>     Bevragen/raadplegen van een openbare ruimte met een woonplaats identificatie en een openbare ruimte naam.     Als expand=ligtInWoonplaats of true dan wordt de woonplaats als geneste resource geleverd.   </li>   <li>     Bevragen/zoeken van alle aan een woonplaats gerelateerde openbare ruimten met de woonplaats identificatie.     Parameter huidig kan worden toegepast.     Expand wordt niet ondersteund.   </li> </ol> Bij alle bovenstaande combinaties wordt paginering ondersteund en kunnen de parameters geldigOp en beschikbaarOp worden gebruikt. Voor paginering, zie: [functionele specificatie paginering](https://github.com/lvbag/BAG-API/blob/master/Features/paginering.feature). Als geldigOp en beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::OpenbareRuimteApi.new
opts = {
  woonplaats_naam: 'Duiven', # String | Naam van een woonplaats object uit de BAG.
  openbare_ruimte_naam: 'Laan van de landinrichtingscommissie Duiven-Westervoort', # String | Naam van een openbare ruimte object uit de BAG.
  woonplaats_identificatie: '2096', # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
  huidig: false, # Boolean | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn.
  geldig_op: Date.parse('2019-06-01'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum 'YYYY-MM-DD'  Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  page: 56, # Integer | Pagina nummer
  page_size: 56, # Integer | Aantal resultaten per pagina
  expand: 'expand_example' # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
}

begin
  # bevragen openbare ruimte(n) op basis van de verschillende combinaties van parameters.
  result = api_instance.zoek_openbare_ruimten(opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling OpenbareRuimteApi->zoek_openbare_ruimten: #{e}"
end
```

#### Using the zoek_openbare_ruimten_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<OpenbareRuimteIOHalCollection>, Integer, Hash)> zoek_openbare_ruimten_with_http_info(opts)

```ruby
begin
  # bevragen openbare ruimte(n) op basis van de verschillende combinaties van parameters.
  data, status_code, headers = api_instance.zoek_openbare_ruimten_with_http_info(opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <OpenbareRuimteIOHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling OpenbareRuimteApi->zoek_openbare_ruimten_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **woonplaats_naam** | **String** | Naam van een woonplaats object uit de BAG. | [optional] |
| **openbare_ruimte_naam** | **String** | Naam van een openbare ruimte object uit de BAG. | [optional] |
| **woonplaats_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. | [optional] |
| **huidig** | **Boolean** | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn. | [optional][default to false] |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#39;YYYY-MM-DD&#39;  Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **page** | **Integer** | Pagina nummer | [optional][default to 1] |
| **page_size** | **Integer** | Aantal resultaten per pagina | [optional][default to 20] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |

### Return type

[**OpenbareRuimteIOHalCollection**](OpenbareRuimteIOHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json

