# BagKadasterClient::PandApi

All URIs are relative to *https://api.bag.acceptatie.kadaster.nl/lvbag/individuelebevragingen/v2*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**pand_geometrie**](PandApi.md#pand_geometrie) | **POST** /panden | bevragen panden met een geometrische locatie. |
| [**pand_identificatie**](PandApi.md#pand_identificatie) | **GET** /panden/{identificatie} | bevragen van een pand met de identificatie van een pand. |
| [**pand_identificatie_voorkomen**](PandApi.md#pand_identificatie_voorkomen) | **GET** /panden/{identificatie}/{versie}/{timestampRegistratieLv} | bevragen voorkomen van een pand met de identificatie van een pand en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG. |
| [**pand_lvc_identificatie**](PandApi.md#pand_lvc_identificatie) | **GET** /panden/{identificatie}/lvc | bevragen levenscyclus van een pand met de identificatie van een pand. |


## pand_geometrie

> <PandIOHalCollection> pand_geometrie(point, opts)

bevragen panden met een geometrische locatie.

Bevragen/raadplegen van een voorkomen van één of meer panden met de geometrische locatie van het pand. Parameter huidig kan worden toegepast. Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::PandApi.new
point = BagKadasterClient::Point.new({type: 'Point', coordinates: [3.56]}) # Point | Geometrisch punt waarop de panden bepaald moeten worden.
opts = {
  geldig_op: Date.parse('2019-04-01'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum `JJJJ-MM-DD` Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  huidig: false, # Boolean | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn.
  content_crs: 'epsg:28992', # String | CRS van de meegegeven geometrie.
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen panden met een geometrische locatie.
  result = api_instance.pand_geometrie(point, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling PandApi->pand_geometrie: #{e}"
end
```

#### Using the pand_geometrie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<PandIOHalCollection>, Integer, Hash)> pand_geometrie_with_http_info(point, opts)

```ruby
begin
  # bevragen panden met een geometrische locatie.
  data, status_code, headers = api_instance.pand_geometrie_with_http_info(point, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <PandIOHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling PandApi->pand_geometrie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **point** | [**Point**](Point.md) | Geometrisch punt waarop de panden bepaald moeten worden. |  |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#x60;JJJJ-MM-DD&#x60; Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **huidig** | **Boolean** | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn. | [optional][default to false] |
| **content_crs** | **String** | CRS van de meegegeven geometrie. | [optional] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**PandIOHalCollection**](PandIOHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/hal+json, application/problem+json


## pand_identificatie

> <PandIOHal> pand_identificatie(identificatie, opts)

bevragen van een pand met de identificatie van een pand.

Bevragen/raadplegen van een voorkomen van een pand met de identificatie van het pand. Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::PandApi.new
identificatie = '0226100000008856' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
opts = {
  geldig_op: Date.parse('2019-04-01'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum `JJJJ-MM-DD` Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen van een pand met de identificatie van een pand.
  result = api_instance.pand_identificatie(identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling PandApi->pand_identificatie: #{e}"
end
```

#### Using the pand_identificatie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<PandIOHal>, Integer, Hash)> pand_identificatie_with_http_info(identificatie, opts)

```ruby
begin
  # bevragen van een pand met de identificatie van een pand.
  data, status_code, headers = api_instance.pand_identificatie_with_http_info(identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <PandIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling PandApi->pand_identificatie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#x60;JJJJ-MM-DD&#x60; Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**PandIOHal**](PandIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## pand_identificatie_voorkomen

> <PandIOHal> pand_identificatie_voorkomen(identificatie, versie, timestamp_registratie_lv, opts)

bevragen voorkomen van een pand met de identificatie van een pand en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.

Bevragen/raadplegen van een voorkomen van een pand met de identificatie van een pand en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::PandApi.new
identificatie = '0226100000008856' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
versie = 1 # Integer | De versie van een voorkomen van een object
timestamp_registratie_lv = '1530403860000' # String | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG
opts = {
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen voorkomen van een pand met de identificatie van een pand en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.
  result = api_instance.pand_identificatie_voorkomen(identificatie, versie, timestamp_registratie_lv, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling PandApi->pand_identificatie_voorkomen: #{e}"
end
```

#### Using the pand_identificatie_voorkomen_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<PandIOHal>, Integer, Hash)> pand_identificatie_voorkomen_with_http_info(identificatie, versie, timestamp_registratie_lv, opts)

```ruby
begin
  # bevragen voorkomen van een pand met de identificatie van een pand en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.
  data, status_code, headers = api_instance.pand_identificatie_voorkomen_with_http_info(identificatie, versie, timestamp_registratie_lv, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <PandIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling PandApi->pand_identificatie_voorkomen_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **versie** | **Integer** | De versie van een voorkomen van een object |  |
| **timestamp_registratie_lv** | **String** | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG |  |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**PandIOHal**](PandIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## pand_lvc_identificatie

> <PandIOLvcHalCollection> pand_lvc_identificatie(identificatie, opts)

bevragen levenscyclus van een pand met de identificatie van een pand.

Bevragen/raadplegen van de levenscyclus van een pand met de identificatie van een pand.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::PandApi.new
identificatie = '0226100000008856' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
opts = {
  gehele_lvc: true, # Boolean | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false). Voor een toelichting zie de [Praktijkhandleiding BAG](https://imbag.github.io/praktijkhandleiding/artikelen/wat-is-het-verschil-tussen-actieve-voorkomens-actuele-voorkomens-en-huidige-voorkomens).
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen levenscyclus van een pand met de identificatie van een pand.
  result = api_instance.pand_lvc_identificatie(identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling PandApi->pand_lvc_identificatie: #{e}"
end
```

#### Using the pand_lvc_identificatie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<PandIOLvcHalCollection>, Integer, Hash)> pand_lvc_identificatie_with_http_info(identificatie, opts)

```ruby
begin
  # bevragen levenscyclus van een pand met de identificatie van een pand.
  data, status_code, headers = api_instance.pand_lvc_identificatie_with_http_info(identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <PandIOLvcHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling PandApi->pand_lvc_identificatie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **gehele_lvc** | **Boolean** | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false). Voor een toelichting zie de [Praktijkhandleiding BAG](https://imbag.github.io/praktijkhandleiding/artikelen/wat-is-het-verschil-tussen-actieve-voorkomens-actuele-voorkomens-en-huidige-voorkomens). | [optional][default to false] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**PandIOLvcHalCollection**](PandIOLvcHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json

