# BagKadasterClient::VerblijfsobjectApi

All URIs are relative to *https://api.bag.acceptatie.kadaster.nl/lvbag/individuelebevragingen/v2*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**verblijfsobject_identificatie**](VerblijfsobjectApi.md#verblijfsobject_identificatie) | **GET** /verblijfsobjecten/{identificatie} | bevragen 1 verblijfsobject met de identificatie van een verblijfsobject. |
| [**verblijfsobject_identificatie_voorkomen**](VerblijfsobjectApi.md#verblijfsobject_identificatie_voorkomen) | **GET** /verblijfsobjecten/{identificatie}/{versie}/{timestampRegistratieLv} | bevragen voorkomen van een verblijfsobject, op basis van de identificatie van een verblijfsobject en de identificatie van een voorkomen |
| [**verblijfsobject_lvc_identificatie**](VerblijfsobjectApi.md#verblijfsobject_lvc_identificatie) | **GET** /verblijfsobjecten/{identificatie}/lvc | bevragen levenscyclus van een verblijfsobject met de identificatie van een verblijfsobject. |
| [**zoek_verblijfsobjecten**](VerblijfsobjectApi.md#zoek_verblijfsobjecten) | **GET** /verblijfsobjecten | bevragen van alle aan een pand gerelateerde verblijfsobjecten (met paginering). |


## verblijfsobject_identificatie

> <VerblijfsobjectIOHal> verblijfsobject_identificatie(identificatie, opts)

bevragen 1 verblijfsobject met de identificatie van een verblijfsobject.

Bevragen/raadplegen van één voorkomen van een Verblijfsobject met de identificatie van een verblijfsobject. Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd. Als expand=heeftAlsHoofdAdres, heeftAlsNevenAdres, maaktDeelUitVan of true, dan worden de gevraagde of alle gerelateerde objecten als geneste resource geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::VerblijfsobjectApi.new
identificatie = '0226010000038820' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
opts = {
  geldig_op: Date.parse('2019-11-23'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum `JJJJ-MM-DD` Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  expand: 'expand_example', # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen 1 verblijfsobject met de identificatie van een verblijfsobject.
  result = api_instance.verblijfsobject_identificatie(identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling VerblijfsobjectApi->verblijfsobject_identificatie: #{e}"
end
```

#### Using the verblijfsobject_identificatie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<VerblijfsobjectIOHal>, Integer, Hash)> verblijfsobject_identificatie_with_http_info(identificatie, opts)

```ruby
begin
  # bevragen 1 verblijfsobject met de identificatie van een verblijfsobject.
  data, status_code, headers = api_instance.verblijfsobject_identificatie_with_http_info(identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <VerblijfsobjectIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling VerblijfsobjectApi->verblijfsobject_identificatie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#x60;JJJJ-MM-DD&#x60; Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**VerblijfsobjectIOHal**](VerblijfsobjectIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## verblijfsobject_identificatie_voorkomen

> <VerblijfsobjectIOHal> verblijfsobject_identificatie_voorkomen(identificatie, versie, timestamp_registratie_lv, opts)

bevragen voorkomen van een verblijfsobject, op basis van de identificatie van een verblijfsobject en de identificatie van een voorkomen

Bevragen/raadplegen van een voorkomen van een verblijfsobject, met de identificatie van een verblijfsobject en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::VerblijfsobjectApi.new
identificatie = '0226010000038820' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
versie = 1 # Integer | De versie van een voorkomen van een object
timestamp_registratie_lv = '1530403860000' # String | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG
opts = {
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen voorkomen van een verblijfsobject, op basis van de identificatie van een verblijfsobject en de identificatie van een voorkomen
  result = api_instance.verblijfsobject_identificatie_voorkomen(identificatie, versie, timestamp_registratie_lv, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling VerblijfsobjectApi->verblijfsobject_identificatie_voorkomen: #{e}"
end
```

#### Using the verblijfsobject_identificatie_voorkomen_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<VerblijfsobjectIOHal>, Integer, Hash)> verblijfsobject_identificatie_voorkomen_with_http_info(identificatie, versie, timestamp_registratie_lv, opts)

```ruby
begin
  # bevragen voorkomen van een verblijfsobject, op basis van de identificatie van een verblijfsobject en de identificatie van een voorkomen
  data, status_code, headers = api_instance.verblijfsobject_identificatie_voorkomen_with_http_info(identificatie, versie, timestamp_registratie_lv, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <VerblijfsobjectIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling VerblijfsobjectApi->verblijfsobject_identificatie_voorkomen_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **versie** | **Integer** | De versie van een voorkomen van een object |  |
| **timestamp_registratie_lv** | **String** | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG |  |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**VerblijfsobjectIOHal**](VerblijfsobjectIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## verblijfsobject_lvc_identificatie

> <VerblijfsobjectIOLvcHalCollection> verblijfsobject_lvc_identificatie(identificatie, opts)

bevragen levenscyclus van een verblijfsobject met de identificatie van een verblijfsobject.

Bevragen/raadplegen van de levenscyclus van een Verblijfsobject met de identificatie van de verblijfsobject.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::VerblijfsobjectApi.new
identificatie = '0226010000038820' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
opts = {
  gehele_lvc: true, # Boolean | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false). Voor een toelichting zie de [Praktijkhandleiding BAG](https://imbag.github.io/praktijkhandleiding/artikelen/wat-is-het-verschil-tussen-actieve-voorkomens-actuele-voorkomens-en-huidige-voorkomens).
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen levenscyclus van een verblijfsobject met de identificatie van een verblijfsobject.
  result = api_instance.verblijfsobject_lvc_identificatie(identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling VerblijfsobjectApi->verblijfsobject_lvc_identificatie: #{e}"
end
```

#### Using the verblijfsobject_lvc_identificatie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<VerblijfsobjectIOLvcHalCollection>, Integer, Hash)> verblijfsobject_lvc_identificatie_with_http_info(identificatie, opts)

```ruby
begin
  # bevragen levenscyclus van een verblijfsobject met de identificatie van een verblijfsobject.
  data, status_code, headers = api_instance.verblijfsobject_lvc_identificatie_with_http_info(identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <VerblijfsobjectIOLvcHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling VerblijfsobjectApi->verblijfsobject_lvc_identificatie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **gehele_lvc** | **Boolean** | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false). Voor een toelichting zie de [Praktijkhandleiding BAG](https://imbag.github.io/praktijkhandleiding/artikelen/wat-is-het-verschil-tussen-actieve-voorkomens-actuele-voorkomens-en-huidige-voorkomens). | [optional][default to false] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**VerblijfsobjectIOLvcHalCollection**](VerblijfsobjectIOLvcHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## zoek_verblijfsobjecten

> <VerblijfsobjectIOHalCollection> zoek_verblijfsobjecten(pand_identificatie, opts)

bevragen van alle aan een pand gerelateerde verblijfsobjecten (met paginering).

Bevragen/zoeken van alle aan een pand gerelateerde verblijfsobjecten, met een pand identificatie en met paginering. Parameter huidig kan worden toegepast. Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd. Voor paginering, zie: [functionele specificatie paginering](https://github.com/lvbag/BAG-API/blob/master/Features/paginering.feature).

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::VerblijfsobjectApi.new
pand_identificatie = '0226100000008856' # String | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten.
opts = {
  huidig: false, # Boolean | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn.
  geldig_op: Date.parse('2019-11-23'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum `JJJJ-MM-DD` Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  page: 56, # Integer | Pagina nummer
  page_size: 56, # Integer | Aantal resultaten per pagina
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen van alle aan een pand gerelateerde verblijfsobjecten (met paginering).
  result = api_instance.zoek_verblijfsobjecten(pand_identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling VerblijfsobjectApi->zoek_verblijfsobjecten: #{e}"
end
```

#### Using the zoek_verblijfsobjecten_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<VerblijfsobjectIOHalCollection>, Integer, Hash)> zoek_verblijfsobjecten_with_http_info(pand_identificatie, opts)

```ruby
begin
  # bevragen van alle aan een pand gerelateerde verblijfsobjecten (met paginering).
  data, status_code, headers = api_instance.zoek_verblijfsobjecten_with_http_info(pand_identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <VerblijfsobjectIOHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling VerblijfsobjectApi->zoek_verblijfsobjecten_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **pand_identificatie** | **String** | Identificatie van een object uit de BAG. Deze is 4 lang bij een woonplaats en 16 lang bij de andere objecten. |  |
| **huidig** | **Boolean** | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn. | [optional][default to false] |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#x60;JJJJ-MM-DD&#x60; Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **page** | **Integer** | Pagina nummer | [optional][default to 1] |
| **page_size** | **Integer** | Aantal resultaten per pagina | [optional][default to 20] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**VerblijfsobjectIOHalCollection**](VerblijfsobjectIOHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json

