# BagKadasterClient::WoonplaatsApi

All URIs are relative to *https://api.bag.acceptatie.kadaster.nl/lvbag/individuelebevragingen/v2*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**woonplaats_geometrie**](WoonplaatsApi.md#woonplaats_geometrie) | **POST** /woonplaatsen | bevragen van een woonplaats met een geometrische locatie. |
| [**woonplaats_identificatie**](WoonplaatsApi.md#woonplaats_identificatie) | **GET** /woonplaatsen/{identificatie} | bevragen van een woonplaats met de identificatie van een woonplaats. |
| [**woonplaats_identificatie_voorkomen**](WoonplaatsApi.md#woonplaats_identificatie_voorkomen) | **GET** /woonplaatsen/{identificatie}/{versie}/{timestampRegistratieLv} | bevragen van een voorkomen van een woonplaats met de identificatie van een woonplaats en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG. |
| [**woonplaats_lvc_identificatie**](WoonplaatsApi.md#woonplaats_lvc_identificatie) | **GET** /woonplaatsen/{identificatie}/lvc | bevragen van de levenscyclus van een woonplaats met de identificatie van een woonplaats. |
| [**woonplaats_naam**](WoonplaatsApi.md#woonplaats_naam) | **GET** /woonplaatsen | bevragen van één of meer woonplaatsen met een woonplaatsnaam. |


## woonplaats_geometrie

> <WoonplaatsIOHalCollection> woonplaats_geometrie(point, opts)

bevragen van een woonplaats met een geometrische locatie.

Bevragen/raadplegen van een voorkomen van een Woonplaats met een geometrische locatie. Parameter huidig kan worden toegepast. Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd.  Als expand=bronhouders, geometrie of true dan worden de gevraagde of alle gerelateerde objecten als geneste resource geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::WoonplaatsApi.new
point = BagKadasterClient::Point.new({type: 'Point', coordinates: [3.56]}) # Point | Geometrisch punt waarop de woonplaatsen bepaald moeten worden.
opts = {
  geldig_op: Date.parse('2019-06-01'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum 'YYYY-MM-DD' Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  huidig: false, # Boolean | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn.
  expand: 'expand_example', # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
  content_crs: 'epsg:28992', # String | CRS van de meegegeven geometrie.
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen van een woonplaats met een geometrische locatie.
  result = api_instance.woonplaats_geometrie(point, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling WoonplaatsApi->woonplaats_geometrie: #{e}"
end
```

#### Using the woonplaats_geometrie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<WoonplaatsIOHalCollection>, Integer, Hash)> woonplaats_geometrie_with_http_info(point, opts)

```ruby
begin
  # bevragen van een woonplaats met een geometrische locatie.
  data, status_code, headers = api_instance.woonplaats_geometrie_with_http_info(point, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <WoonplaatsIOHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling WoonplaatsApi->woonplaats_geometrie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **point** | [**Point**](Point.md) | Geometrisch punt waarop de woonplaatsen bepaald moeten worden. |  |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#39;YYYY-MM-DD&#39; Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **huidig** | **Boolean** | Indicatie dat alleen actuele object voorkomens zonder eindstatus gewenst zijn. | [optional][default to false] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |
| **content_crs** | **String** | CRS van de meegegeven geometrie. | [optional] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**WoonplaatsIOHalCollection**](WoonplaatsIOHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/hal+json, application/problem+json


## woonplaats_identificatie

> <WoonplaatsIOHal> woonplaats_identificatie(identificatie, opts)

bevragen van een woonplaats met de identificatie van een woonplaats.

Bevragen/raadplegen van een voorkomen van een Woonplaats met de identificatie van de woonplaats.  Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd. Als expand=bronhouders, geometrie of true dan worden de gevraagde of alle gerelateerde objecten als geneste resource geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::WoonplaatsApi.new
identificatie = '2096' # String | De identificatie van een BAG object. Deze is 4 cijfers lang bij een woonplaats.
opts = {
  geldig_op: Date.parse('2019-06-01'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum 'YYYY-MM-DD' Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  expand: 'expand_example', # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen van een woonplaats met de identificatie van een woonplaats.
  result = api_instance.woonplaats_identificatie(identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling WoonplaatsApi->woonplaats_identificatie: #{e}"
end
```

#### Using the woonplaats_identificatie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<WoonplaatsIOHal>, Integer, Hash)> woonplaats_identificatie_with_http_info(identificatie, opts)

```ruby
begin
  # bevragen van een woonplaats met de identificatie van een woonplaats.
  data, status_code, headers = api_instance.woonplaats_identificatie_with_http_info(identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <WoonplaatsIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling WoonplaatsApi->woonplaats_identificatie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **identificatie** | **String** | De identificatie van een BAG object. Deze is 4 cijfers lang bij een woonplaats. |  |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#39;YYYY-MM-DD&#39; Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**WoonplaatsIOHal**](WoonplaatsIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## woonplaats_identificatie_voorkomen

> <WoonplaatsIOHal> woonplaats_identificatie_voorkomen(identificatie, versie, timestamp_registratie_lv, opts)

bevragen van een voorkomen van een woonplaats met de identificatie van een woonplaats en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.

Bevragen/raadplegen van een voorkomen van een Woonplaats met de identificatie van een woonplaats en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG. Als expand=bronhouders, geometrie of true dan worden de gevraagde of alle gerelateerde objecten als geneste resource geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::WoonplaatsApi.new
identificatie = '2096' # String | De identificatie van een BAG object. Deze is 4 cijfers lang bij een woonplaats.
versie = 1 # Integer | De versie van een voorkomen van een object
timestamp_registratie_lv = '1530403860000' # String | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG
opts = {
  expand: 'expand_example', # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen van een voorkomen van een woonplaats met de identificatie van een woonplaats en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.
  result = api_instance.woonplaats_identificatie_voorkomen(identificatie, versie, timestamp_registratie_lv, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling WoonplaatsApi->woonplaats_identificatie_voorkomen: #{e}"
end
```

#### Using the woonplaats_identificatie_voorkomen_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<WoonplaatsIOHal>, Integer, Hash)> woonplaats_identificatie_voorkomen_with_http_info(identificatie, versie, timestamp_registratie_lv, opts)

```ruby
begin
  # bevragen van een voorkomen van een woonplaats met de identificatie van een woonplaats en de identificatie van een voorkomen, bestaande uit een versie en een timestamp van het tijdstip van registratie in de LV BAG.
  data, status_code, headers = api_instance.woonplaats_identificatie_voorkomen_with_http_info(identificatie, versie, timestamp_registratie_lv, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <WoonplaatsIOHal>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling WoonplaatsApi->woonplaats_identificatie_voorkomen_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **identificatie** | **String** | De identificatie van een BAG object. Deze is 4 cijfers lang bij een woonplaats. |  |
| **versie** | **Integer** | De versie van een voorkomen van een object |  |
| **timestamp_registratie_lv** | **String** | Een timestamp van het tijdstip waarop een voorkomen is geregistreerd in de LV BAG |  |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**WoonplaatsIOHal**](WoonplaatsIOHal.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## woonplaats_lvc_identificatie

> <WoonplaatsIOLvcHalCollection> woonplaats_lvc_identificatie(identificatie, opts)

bevragen van de levenscyclus van een woonplaats met de identificatie van een woonplaats.

Bevragen/raadplegen van de levenscyclus van een Woonplaats met de identificatie van de woonplaats. Als expand=bronhouders, geometrie of true dan worden de gevraagde of alle gerelateerde objecten als geneste resource geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::WoonplaatsApi.new
identificatie = '2096' # String | De identificatie van een BAG object. Deze is 4 cijfers lang bij een woonplaats.
opts = {
  gehele_lvc: true, # Boolean | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false). Voor een toelichting zie de [Praktijkhandleiding BAG](https://imbag.github.io/praktijkhandleiding/artikelen/wat-is-het-verschil-tussen-actieve-voorkomens-actuele-voorkomens-en-huidige-voorkomens).
  expand: 'expand_example', # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen van de levenscyclus van een woonplaats met de identificatie van een woonplaats.
  result = api_instance.woonplaats_lvc_identificatie(identificatie, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling WoonplaatsApi->woonplaats_lvc_identificatie: #{e}"
end
```

#### Using the woonplaats_lvc_identificatie_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<WoonplaatsIOLvcHalCollection>, Integer, Hash)> woonplaats_lvc_identificatie_with_http_info(identificatie, opts)

```ruby
begin
  # bevragen van de levenscyclus van een woonplaats met de identificatie van een woonplaats.
  data, status_code, headers = api_instance.woonplaats_lvc_identificatie_with_http_info(identificatie, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <WoonplaatsIOLvcHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling WoonplaatsApi->woonplaats_lvc_identificatie_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **identificatie** | **String** | De identificatie van een BAG object. Deze is 4 cijfers lang bij een woonplaats. |  |
| **gehele_lvc** | **Boolean** | Filtert naast geldige voorkomens ook de voorkomens die uit de geldige levenscyclus van het object zijn verwijderd. Als deze parameter wordt weggelaten worden alleen geldige voorkomens geretourneerd (default is false). Voor een toelichting zie de [Praktijkhandleiding BAG](https://imbag.github.io/praktijkhandleiding/artikelen/wat-is-het-verschil-tussen-actieve-voorkomens-actuele-voorkomens-en-huidige-voorkomens). | [optional][default to false] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**WoonplaatsIOLvcHalCollection**](WoonplaatsIOLvcHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json


## woonplaats_naam

> <WoonplaatsIOHalCollection> woonplaats_naam(naam, opts)

bevragen van één of meer woonplaatsen met een woonplaatsnaam.

Bevragen/raadplegen van één voorkomen van één of meer woonplaatsen met een woonplaatsnaam. Als geldigOp en/of beschikbaarOp niet wordt opgegeven, worden de actuele gegevens geleverd.  Als expand=bronhouders, geometrie of true dan worden de gevraagde of alle gerelateerde objecten als geneste resource geleverd.

### Examples

```ruby
require 'time'
require 'bag_kadaster_client'
# setup authorization
BagKadasterClient.configure do |config|
  # Configure API key authorization: apiKeyBAG
  config.api_key['apiKeyBAG'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKeyBAG'] = 'Bearer'
end

api_instance = BagKadasterClient::WoonplaatsApi.new
naam = 'Duiven' # String | Naam van een woonplaats object uit de BAG.
opts = {
  geldig_op: Date.parse('2019-06-01'), # Date | Filtert op objecten die geldig zijn op de opgegeven datum 'YYYY-MM-DD' Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  beschikbaar_op: Time.parse('2013-10-20T19:20:30+01:00'), # Time | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd `YYYY-MM-DDThh:mm:ss.sss' Hierin kunnen de seconden ':ss' en milliseconden '.sss' of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde ':00' respectievelijk '.000'. Indien er voor de milliseconden '.sss' meer dan 3 cijfers worden opgegeven, bv. '.12345', dan wordt dit afgekapt tot '.123'. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen. 
  expand: 'expand_example', # String | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt.
  accept_crs: 'epsg:28992' # String | Gewenste CRS van de coördinaten in de response.
}

begin
  # bevragen van één of meer woonplaatsen met een woonplaatsnaam.
  result = api_instance.woonplaats_naam(naam, opts)
  p result
rescue BagKadasterClient::ApiError => e
  puts "Error when calling WoonplaatsApi->woonplaats_naam: #{e}"
end
```

#### Using the woonplaats_naam_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<WoonplaatsIOHalCollection>, Integer, Hash)> woonplaats_naam_with_http_info(naam, opts)

```ruby
begin
  # bevragen van één of meer woonplaatsen met een woonplaatsnaam.
  data, status_code, headers = api_instance.woonplaats_naam_with_http_info(naam, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <WoonplaatsIOHalCollection>
rescue BagKadasterClient::ApiError => e
  puts "Error when calling WoonplaatsApi->woonplaats_naam_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **naam** | **String** | Naam van een woonplaats object uit de BAG. |  |
| **geldig_op** | **Date** | Filtert op objecten die geldig zijn op de opgegeven datum &#39;YYYY-MM-DD&#39; Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **beschikbaar_op** | **Time** | Filtert op objecten die beschikbaar zijn op de opgegeven datum en tijd &#x60;YYYY-MM-DDThh:mm:ss.sss&#39; Hierin kunnen de seconden &#39;:ss&#39; en milliseconden &#39;.sss&#39; of alleen de milliseconden conform ISO 8601 specificatie worden weggelaten, in dat geval krijgen deze automatisch de waarde &#39;:00&#39; respectievelijk &#39;.000&#39;. Indien er voor de milliseconden &#39;.sss&#39; meer dan 3 cijfers worden opgegeven, bv. &#39;.12345&#39;, dan wordt dit afgekapt tot &#39;.123&#39;. Deze parameters komen uit de API strategie, het hoofdstuk tijdreizen.  | [optional] |
| **expand** | **String** | Hier kan aangegeven worden welke gerelateerde resources meegeladen moeten worden. Resources en velden van resources die gewenst zijn kunnen in de expand parameter kommagescheiden worden opgegeven. Specifieke velden van resource kunnen worden opgegeven door het opgeven van de resource-naam gevolgd door de veldnaam, met daartussen een punt. | [optional] |
| **accept_crs** | **String** | Gewenste CRS van de coördinaten in de response. | [optional] |

### Return type

[**WoonplaatsIOHalCollection**](WoonplaatsIOHalCollection.md)

### Authorization

[apiKeyBAG](../README.md#apiKeyBAG)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/hal+json, application/problem+json

